@@ -116,6 +116,10 @@ def pl_isin(col, arr):
     equalities = list(map(lambda t: pl.col(col) == t, arr))
     return functools.reduce(lambda a, b: a | b, equalities)
 
+def pl_notin(col, arr):
+    equalities = list(map(lambda t: pl.col(col) != t, arr))
+    return functools.reduce(lambda a, b: a & b, equalities)
+
 def filter_bed_file_by_(bed_file_1, bed_file_2, output_file):
     # generated by OpenAI Codex
 
@@ -133,9 +137,10 @@ def filter_df_by_tfactor_fastas(df, folder, derive_target_col = False):
     all_df_targets = df.get_column('target').unique().to_list()
 
     all_df_targets_with_parsed_name = [(target, parse_gene_name(target)) for target in all_df_targets]
-    unknown_targets = [target for target, parsed_target_name in all_df_targets_with_parsed_name if parsed_target_name not in present_target_names]
+    unknown_targets = [target for target, parsed_target_name in all_df_targets_with_parsed_name for parsed_target_name_sub_el in parsed_target_name if parsed_target_name_sub_el not in present_target_names]
 
-    df = df.filter(pl_isin('target', unknown_targets))
+    if len(unknown_targets) > 0:
+        df = df.filter(pl_notin('target', unknown_targets))
     return df
 
 def generate_random_ranges_from_fasta(
