@@ -144,6 +144,8 @@ class AdapterModel(nn.Module):
         self.enformer = enformer
         enformer_dim = enformer.dim * 2
 
+        self.norm_seq_embed = nn.LayerNorm(enformer_dim)
+
         # contextual embedding related variables
 
         assert free_text_embed_method in {'cls', 'mean_pool'}, 'must be either cls or mean_pool'
@@ -234,6 +236,8 @@ class AdapterModel(nn.Module):
         with enformer_context:
             seq_embed = enformer_forward(seq, return_only_embeddings = True)
 
+        seq_embed = self.norm_seq_embed(seq_embed)
+
         # protein related embeddings
 
         if self.use_esm_embeds:
@@ -344,6 +348,8 @@ class AttentionAdapterModel(nn.Module):
         self.enformer = enformer
         enformer_dim = enformer.dim * 2
 
+        self.norm_seq_embed = nn.LayerNorm(enformer_dim)
+
         # contextual embedding related variables
 
         assert free_text_embed_method in {'cls', 'mean_pool'}, 'must be either cls or mean_pool'
@@ -446,6 +452,8 @@ class AttentionAdapterModel(nn.Module):
         with enformer_context:
             seq_embed = enformer_forward(seq, return_only_embeddings = True)
 
+        seq_embed = self.norm_seq_embed(seq_embed)
+
         # protein related embeddings
 
         if self.use_esm_embeds:
@@ -552,6 +560,8 @@ class HyperTransformerAdapterModel(nn.Module):
         self.enformer = enformer
         enformer_dim = enformer.dim * 2
 
+        self.norm_seq_embed = nn.LayerNorm(enformer_dim)
+
         # contextual embedding related variables
 
         assert free_text_embed_method in {'cls', 'mean_pool'}, 'must be either cls or mean_pool'
@@ -658,6 +668,8 @@ class HyperTransformerAdapterModel(nn.Module):
         with enformer_context:
             seq_embed = enformer_forward(seq, return_only_embeddings = True)
 
+        seq_embed = self.norm_seq_embed(seq_embed)
+
         # protein related embeddings
 
         if self.use_esm_embeds:
